summaryrefslogtreecommitdiffstats
path: root/media
diff options
context:
space:
mode:
authorimasaki@google.com <imasaki@google.com@0039d316-1c4b-4281-b951-d872f2087c98>2011-11-11 23:25:39 +0000
committerimasaki@google.com <imasaki@google.com@0039d316-1c4b-4281-b951-d872f2087c98>2011-11-11 23:25:39 +0000
commit1dc82ffc4d82464d8dee9153f7b6302c0b6243f4 (patch)
tree8ded48dff6bed3835c7f56cb4dc596cba9f496ab /media
parent3c149c69609840180c178b04fdb3bbacf77ca78f (diff)
downloadchromium_src-1dc82ffc4d82464d8dee9153f7b6302c0b6243f4.zip
chromium_src-1dc82ffc4d82464d8dee9153f7b6302c0b6243f4.tar.gz
chromium_src-1dc82ffc4d82464d8dee9153f7b6302c0b6243f4.tar.bz2
Adding passing rate in stats csv file in the layout test analyzer.
Review URL: http://codereview.chromium.org/8539024 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@109725 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'media')
-rw-r--r--media/tools/layout_tests/layouttest_analyzer_helpers.py7
-rw-r--r--media/tools/layout_tests/layouttest_analyzer_helpers_unittest.py2
2 files changed, 5 insertions, 4 deletions
diff --git a/media/tools/layout_tests/layouttest_analyzer_helpers_unittest.py b/media/tools/layout_tests/layouttest_analyzer_helpers_unittest.py
index 2301d52..769c6b8 100644
--- a/media/tools/layout_tests/layouttest_analyzer_helpers_unittest.py
+++ b/media/tools/layout_tests/layouttest_analyzer_helpers_unittest.py
@@ -188,7 +188,7 @@ class TestLayoutTestAnalyzerHelpers(unittest.TestCase):
analyzerResultMapBase = (
layouttest_analyzer_helpers.AnalyzerResultMap.Load(file_path))
data, issues_txt = analyzerResultMapBase.ConvertToCSVText('11-10-10-2011')
- self.assertEquals(data, '11-10-10-2011,204,36,10')
+ self.assertEquals(data, '11-10-10-2011,204,36,10,95')
expected_issues_txt = """\
BUGWK,66310,TEXT PASS,media/media-blocked-by-beforeload.html,DEBUG TEXT PASS,\
media/video-source-error.html,
diff --git a/media/tools/layout_tests/layouttest_analyzer_helpers.py b/media/tools/layout_tests/layouttest_analyzer_helpers.py
index 18d844e..405168e 100644
--- a/media/tools/layout_tests/layouttest_analyzer_helpers.py
+++ b/media/tools/layout_tests/layouttest_analyzer_helpers.py
@@ -146,9 +146,9 @@ class AnalyzerResultMap:
a tuple of stats and issues_txt
stats: analyzer result in CSV format that shows:
(current_time, the number of tests, the number of skipped tests,
the number of failing tests)
For example,
- "2011-11-10-15,204,22,12"
+ "2011-11-10-15,204,22,12,94"
issues_txt: issues listed in CSV format that shows:
(BUGWK or BUGCR, bug number, the test expectation entry,
the name of the test)
@@ -158,7 +158,8 @@ class AnalyzerResultMap:
"""
stats = ','.join([current_time, str(len(self.result_map['whole'].keys())),
str(len(self.result_map['skip'].keys())),
- str(len(self.result_map['nonskip'].keys()))])
+ str(len(self.result_map['nonskip'].keys())),
+ str(self.GetPassingRate())])
issues_txt = ''
for bug_txt, test_info_list in (
self.GetListOfBugsForNonSkippedTests().iteritems()):
@@ -146,9 +146,9 @@ class AnalyzerResultMap:
stats: analyzer result in CSV format that shows:
(current_time, the number of tests, the number of skipped tests,
- the number of failing tests)
+ the number of failing tests, passing rate)
For example,